aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rw-r--r--tests/test-external-open-lib-command.el (renamed from tests/test-external-open-command.el)10
-rw-r--r--tests/test-external-open-lib-launcher-p.el (renamed from tests/test-external-open-launcher-p.el)10
2 files changed, 10 insertions, 10 deletions
diff --git a/tests/test-external-open-command.el b/tests/test-external-open-lib-command.el
index b408b305..7f54442c 100644
--- a/tests/test-external-open-command.el
+++ b/tests/test-external-open-lib-command.el
@@ -1,7 +1,7 @@
-;;; test-external-open-command.el --- Tests for cj/external-open-command -*- lexical-binding: t; -*-
+;;; test-external-open-lib-command.el --- Tests for cj/external-open-command -*- lexical-binding: t; -*-
;;; Commentary:
;; Unit tests for `cj/external-open-command' in external-open.el. The
;; function dispatches on host-environment predicates to return the
;; appropriate "open" command: xdg-open on Linux, open on macOS,
;; start on Windows. Returns nil for unsupported hosts (callers that
@@ -16,7 +16,7 @@
(setq package-user-dir (expand-file-name "elpa" user-emacs-directory))
(package-initialize)
(add-to-list 'load-path (expand-file-name "modules" user-emacs-directory))
-(require 'external-open)
+(require 'external-open-lib)
(defmacro test-eoc--with-host (linux macos windows &rest body)
"Run BODY with env-*-p predicates stubbed to LINUX, MACOS, WINDOWS."
@@ -61,5 +61,5 @@ user-error with a clear message."
(test-eoc--with-host nil nil nil
(should-not (cj/external-open-command))))
-(provide 'test-external-open-command)
-;;; test-external-open-command.el ends here
+(provide 'test-external-open-lib-command)
+;;; test-external-open-lib-command.el ends here
@@ -1,7 +1,7 @@
;;; Commentary:
-;; Unit tests for `cj/external-open-command' in external-open.el. The
+;; Unit tests for `cj/external-open-command' in external-open-lib.el. The
;; function dispatches on host-environment predicates to return the
;; appropriate "open" command: xdg-open on Linux, open on macOS,
diff --git a/tests/test-external-open-launcher-p.el b/tests/test-external-open-lib-launcher-p.el
index 4aca3a55..928293b4 100644
--- a/tests/test-external-open-launcher-p.el
+++ b/tests/test-external-open-lib-launcher-p.el
@@ -1,7 +1,7 @@
-;;; test-external-open-launcher-p.el --- Tests for cj/external-open-launcher-p -*- lexical-binding: t; -*-
+;;; test-external-open-lib-launcher-p.el --- Tests for cj/external-open-launcher-p -*- lexical-binding: t; -*-
;;; Commentary:
;; Unit tests for `cj/external-open-launcher-p' in external-open.el.
;; The predicate returns t for desktop launcher commands (xdg-open,
;; open, start) that need `call-process' with a zero buffer argument
;; to fully detach from Emacs. Anything else returns nil.
@@ -14,7 +14,7 @@
(setq package-user-dir (expand-file-name "elpa" user-emacs-directory))
(package-initialize)
(add-to-list 'load-path (expand-file-name "modules" user-emacs-directory))
-(require 'external-open)
+(require 'external-open-lib)
;;; Normal cases
@@ -51,5 +51,5 @@
"Error: nil input is handled gracefully (not in the launcher list)."
(should-not (cj/external-open-launcher-p nil)))
-(provide 'test-external-open-launcher-p)
-;;; test-external-open-launcher-p.el ends here
+(provide 'test-external-open-lib-launcher-p)
+;;; test-external-open-lib-launcher-p.el ends here
@@ -1,7 +1,7 @@
;;; Commentary:
-;; Unit tests for `cj/external-open-launcher-p' in external-open.el.
+;; Unit tests for `cj/external-open-launcher-p' in external-open-lib.el.
;; The predicate returns t for desktop launcher commands (xdg-open,
;; open, start) that need `call-process' with a zero buffer argument